==> dip_client_sdk-1.0.0.tar.gz: example/TestGroup.dart <==
import '../lib/dip_client_sdk.dart';

void main() async {
	var dipClient = new DipClient(DipClient.ENV_INT);
	print("dipClient created");

	var userSeqNum = await dipClient.getSeqNum(seqName: "test-user-seqnum");
	var userSeqNumStr = userSeqNum.toString();
	print("test user seqeuence number = " + userSeqNumStr);

    var userName = "test-user-" + userSeqNumStr + "@dip-test.com";
    var password = "1111";
    var name = "테스트사용자(group)";

    await dipClient.createUser(
        userName: userName,
        password: password,
        name: name
    );
    print("test user created: username = " + userName);

    await dipClient.authenticate(
        userName: userName,
        password: password
    );
    print("test user authenticated: username = " + userName);

	var groupCategory = "test-group";
	var groupNamePrefix = "test-group";
	var groupName = groupNamePrefix + "-" + userSeqNumStr;

	await dipClient.createGroup(
		category: groupCategory,
		name: groupName,
		groupOwner: userName,
		attrs: {
			'attr1': 'test attribute'
		},
	);
	print("test group created: groupCategory/groupName = " + groupCategory + '/' + groupName);

    var identityOwner = userName;
    var identityCategory = '/test-category';
    var identityAttrs = {
        'attr1': 'attr1_value'
    };
    var identityDattrs = {
        'dattr1': 'dattr1_value'
    };

    var identityId = await dipClient.createIdentity(
        identityOwner: identityOwner,
        category: identityCategory,
        attrs: identityAttrs,
        dattrs: identityDattrs,
        //resources: identityResources,
        isTemporary: false,
    );
    print("test identity created: identityId = " + identityId);

	await dipClient.addToGroup(
		groupCategory: groupCategory,
		groupName: groupName,
		memberType: "id",
		memberId: identityId
	);
	print("member added to the group: memberType/memberId = id/" + identityId);

	var groups;

	groups = await dipClient.findGroups(
		category: groupCategory,
		namePrefix: groupNamePrefix,
	);
	print("test groups found: groups = " + groups.toString());

	await dipClient.removeFromGroup(
		groupCategory: groupCategory,
		groupName: groupName,
		memberType: "id",
		memberId: identityId
	);
	print("member removed from the group: memberType/memberId = id/" + identityId);

	groups = await dipClient.findGroups(
		category: groupCategory,
		namePrefix: groupNamePrefix,
	);
	print("test groups found: groups = " + groups.toString());

	var members = await dipClient.getGroupMembers(
		groupCategory: groupCategory,
		groupName: groupName
	);
	print("member of the group = " + members.toString());
}

==> dip_client_sdk-1.1.6.tar.gz: example/TestGroup.dart <==
import '../lib/dip_client_sdk.dart';

void main() async {
	var dipClient = new DipClient(DipClient.ENV_INT);
	print("dipClient created");

	var userSeqNum = await dipClient.getSeqNum(seqName: "test-user-seqnum");
	var userSeqNumStr = userSeqNum.toString();
	print("test user seqeuence number = " + userSeqNumStr);

    var userName = "test-user-" + userSeqNumStr + "@dip-test.com";
    var password = "1111";
    var name = "테스트사용자(group)";

    await dipClient.createUser(
        userName: userName,
        password: password,
        name: name
    );
    print("test user created: username = " + userName);

    await dipClient.authenticate(
        userName: userName,
        password: password
    );
    print("test user authenticated: username = " + userName);

	var groupCategory = "test-group";
	var groupNamePrefix = "test-group";
	var groupName = groupNamePrefix + "-" + userSeqNumStr;

	await dipClient.createGroup(
		category: groupCategory,
		name: groupName,
		groupOwner: userName,
		attrs: {
			'attr1': 'test attribute'
		},
	);
	print("test group created: groupCategory/groupName = " + groupCategory + '/' + groupName);

    var identityOwner = userName;
    var identityCategory = '/test-category';
    var identityAttrs = {
        'attr1': 'attr1_value'
    };
    var identityDattrs = {
        'dattr1': 'dattr1_value'
    };

    var identityId = await dipClient.createIdentity(
        identityOwner: identityOwner,
        category: identityCategory,
        attrs: identityAttrs,
        dattrs: identityDattrs,
        //resources: identityResources,
        isTemporary: false,
    );
    print("test identity created: identityId = " + identityId);

	await dipClient.addToGroup(
		groupCategory: groupCategory,
		groupName: groupName,
		memberType: "id",
		memberId: identityId,
		memberName: 'memberName',
	);
	print("member added to the group: memberType/memberId = id/" + identityId);

	var groups;

	groups = await dipClient.findGroups(
		category: groupCategory,
		namePrefix: groupNamePrefix,
	);
	print("test groups found: groups = " + groups.toString());

	await dipClient.removeFromGroup(
		groupCategory: groupCategory,
		groupName: groupName,
		memberType: "id",
		memberName: 'memberName'
	);
	print("member removed from the group: memberType/memberId = id/" + identityId);

	groups = await dipClient.findGroups(
		category: groupCategory,
		namePrefix: groupNamePrefix,
	);
	print("test groups found: groups = " + groups.toString());

	var members = await dipClient.getGroupMembers(
		groupCategory: groupCategory,
		groupName: groupName
	);
	print("member of the group = " + members.toString());
}
